Crate tpm2_device

Crate tpm2_device 

Structs

TpmDevice
TpmPolicySession
Represents an active TPM policy session.
TpmPolicySessionBuilder
A builder for creating a TPM policy session.
TpmPosixDevice
A TpmTransport backed by a Linux TPM character device.
TpmPosixDeviceBuilder
A builder for constructing a TpmPosixDevice.
TpmResponder
The responder end of a TpmTransport, for serving TPM commands.
TpmStreamTransport
A TpmTransport over any blocking byte stream.

Enums

TpmDeviceError
Errors that can occur when talking to a TPM device.

Traits

TpmTransport
A bidirectional, frame-oriented transport for marshaled TPM frames.

Functions

read_frame
Reads one complete TPM frame from a blocking stream into buf.
with_device
Executes a closure with a mutable reference to a TpmDevice.
write_frame
Writes one complete marshaled TPM frame to a blocking stream and flushes it.