TpmDeviceError

Enum TpmDeviceError 

pub enum TpmDeviceError {
Show 17 variants AlreadyBorrowed, CapabilityMissing(TpmCap), Interrupted, InvalidCc(TpmCc), InvalidResponse, Io(Error), Marshal(TpmProtocolError), NotAvailable, OperationFailed, PcrBanksNotAvailable, PcrBankSelectionMismatch, ResponseMismatch(TpmCc), Timeout, TpmRc(TpmRc), TrailingData, Unmarshal(TpmProtocolError), UnexpectedEof,
}
Errors that can occur when talking to a TPM device.

Variants



AlreadyBorrowed

The TPM device is already mutably borrowed.



CapabilityMissing(TpmCap)

The requested capability is not available from the TPM.



Interrupted



InvalidCc(TpmCc)

An invalid command code was used.



InvalidResponse

The TPM returned an invalid or malformed response.



Io(Error)

An I/O error occurred when accessing the TPM device.



Marshal(TpmProtocolError)

Marshaling a TPM protocol encoded object failed.



NotAvailable

No TPM device is available.



OperationFailed

The requested operation could not be completed.



PcrBanksNotAvailable

No PCR banks are available on the TPM.



PcrBankSelectionMismatch

The PCR selection masks differ between active banks.



ResponseMismatch(TpmCc)

The TPM response did not match the expected command code.



Timeout

The TPM command timed out.



TpmRc(TpmRc)

The TPM returned an error code.



TrailingData

Trailing data after the response.



Unmarshal(TpmProtocolError)

Unmarshaling a TPM protocol encoded object failed.



UnexpectedEof

An unexpected end-of-file was encountered.