TpmDeviceBuilder

Struct TpmDeviceBuilder 

pub struct TpmDeviceBuilder { /* private fields */ }
A builder for constructing a TpmDevice.

Implementations

Source

impl TpmDeviceBuilder

pub fn with_path<P: AsRef<Path>>(self, path: P) -> Self

Sets the device file path.

pub fn with_timeout(self, timeout: Duration) -> Self

Sets the operation timeout.

pub fn with_interrupted<F>(self, handler: F) -> Self
where F: Fn() -> bool + 'static,

Sets the interruption check callback.

pub fn build(self) -> Result<TpmDevice, TpmDeviceError>

Opens the TPM device file and constructs the TpmDevice.

Errors

Returns Io when the device file cannot be opened and Nix when configuring the file descriptor flags fails.