TpmPolicySession

Struct TpmPolicySession 

pub struct TpmPolicySession { /* private fields */ }
Represents an active TPM policy session.

Implementations

Source

impl TpmPolicySession

pub fn builder() -> TpmPolicySessionBuilder

Creates a new builder for TpmPolicySession.

pub fn handle(&self) -> TpmHandle

Returns the session handle.

pub fn attributes(&self) -> TpmaSession

Returns the session attributes.

pub fn hash_alg(&self) -> TpmAlgId

Returns the hash algorithm used by the session.

pub fn nonce_tpm(&self) -> &Tpm2bNonce

Returns the nonce generated by the TPM.

pub fn run( &self, device: &mut TpmDevice, commands: Vec<(TpmCommand, TpmAuthCommands)>, ) -> Result<(), TpmDeviceError>

Applies a list of policy commands to this session.

This method iterates through the provided commands, updates the first handle of each command (or second for PolicySecret) to point to this session, and transmits them to the device.

Errors

Returns InvalidCc when a command is not a supported policy command. Returns other TpmDeviceError variants when TpmDevice::transmit fails.

pub fn flush(&self, device: &mut TpmDevice) -> Result<(), TpmDeviceError>

Flushes the session context from the TPM.

Errors

Returns other TpmDeviceError variants when TpmDevice::transmit fails.