Structs
- TpmDevice
- TpmPolicy
Session - Represents an active TPM policy session.
- TpmPolicy
Session Builder - A builder for creating a TPM policy session.
- TpmPosix
Device - A
TpmTransportbacked by a Linux TPM character device. - TpmPosix
Device Builder - A builder for constructing a
TpmPosixDevice. - TpmResponder
- The responder end of a
TpmTransport, for serving TPM commands. - TpmStream
Transport - A
TpmTransportover any blocking byte stream.
Enums
- TpmDevice
Error - Errors that can occur when talking to a TPM device.
Traits
- TpmTransport
- A bidirectional, frame-oriented transport for marshaled TPM frames.
Functions
- read_
frame - Reads one complete TPM frame from a blocking stream into
buf. - with_
device - Executes a closure with a mutable reference to a
TpmDevice. - write_
frame - Writes one complete marshaled TPM frame to a blocking stream and flushes it.