#[non_exhaustive]pub enum TpmDeviceError {
Show 17 variants
AlreadyBorrowed,
CapabilityMissing(TpmCap),
Interrupted,
InvalidCc(TpmCc),
InvalidResponse,
Io(Error),
Marshal(TpmError),
NotAvailable,
PcrBanksNotAvailable,
PcrBankSelectionMismatch,
ResponseMismatch(TpmCc),
Timeout,
TpmRc(TpmRc),
TrailingData,
Unmarshal(TpmError),
UnexpectedEof,
UnsupportedAlgorithm(TpmAlgId),
}Expand description
Errors that can occur when talking to a TPM device.
Display renders only the variant name as lowercase space-separated words
(e.g. UnexpectedEof becomes unexpected eof).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AlreadyBorrowed
The TPM device is already mutably borrowed.
CapabilityMissing(TpmCap)
The requested capability is not available from the TPM.
Interrupted
The operation was interrupted by the caller.
InvalidCc(TpmCc)
An invalid command code was used.
InvalidResponse
The TPM returned an invalid or malformed response.
Io(Error)
An I/O error occurred when accessing the TPM device.
Marshal(TpmError)
Marshaling a TPM protocol encoded object failed.
NotAvailable
No TPM device is available.
PcrBanksNotAvailable
No PCR banks are available on the TPM.
PcrBankSelectionMismatch
The PCR selection masks differ between active banks.
ResponseMismatch(TpmCc)
The TPM response did not match the expected command code.
Timeout
The TPM command timed out.
TpmRc(TpmRc)
The TPM returned an error code.
TrailingData
Trailing data after the response.
Unmarshal(TpmError)
Unmarshaling a TPM protocol encoded object failed.
UnexpectedEof
An unexpected end-of-file was encountered.
UnsupportedAlgorithm(TpmAlgId)
The requested algorithm is not supported.