pub enum TpmDeviceError {
Show 15 variants
AlreadyBorrowed,
CapabilityMissing(TpmCap),
Interrupted,
InvalidResponse,
Io(Error),
Marshal(TpmProtocolError),
NotAvailable,
OperationFailed,
PcrBanksNotAvailable,
PcrBankSelectionMismatch,
ResponseMismatch(TpmCc),
Timeout,
TpmRc(TpmRc),
Unmarshal(TpmProtocolError),
UnexpectedEof,
}Expand description
Errors that can occur when talking to a TPM device.
Variants
AlreadyBorrowed
CapabilityMissing(TpmCap)
Interrupted
InvalidResponse
Io(Error)
Marshal(TpmProtocolError)
Marshaling a TPM protocol encoded object failed.
NotAvailable
OperationFailed
PcrBanksNotAvailable
PcrBankSelectionMismatch
ResponseMismatch(TpmCc)
The TPM response did not match the expected command code.
Timeout
TpmRc(TpmRc)
Unmarshal(TpmProtocolError)
Unmarshaling a TPM protocol encoded object failed.
UnexpectedEof