pub struct TpmPolicySession { /* private fields */ }Expand description
Represents an active TPM policy session.
Implementations
Sourceimpl TpmPolicySession
impl TpmPolicySession
Sourcepub fn builder() -> TpmPolicySessionBuilder
pub fn builder() -> TpmPolicySessionBuilder
Creates a new builder for TpmPolicySession.
Sourcepub fn attributes(&self) -> TpmaSession
pub fn attributes(&self) -> TpmaSession
Returns the session attributes.
Sourcepub fn nonce_tpm(&self) -> &Tpm2bNonce
pub fn nonce_tpm(&self) -> &Tpm2bNonce
Returns the nonce generated by the TPM.
Sourcepub fn run(
&self,
device: &mut TpmDevice,
commands: Vec<(TpmCommand, TpmAuthCommands)>,
) -> Result<(), TpmDeviceError>
pub fn run( &self, device: &mut TpmDevice, commands: Vec<(TpmCommand, TpmAuthCommands)>, ) -> Result<(), TpmDeviceError>
Applies a list of policy commands to this session.
This method iterates through the provided commands, updates the first handle
of each command (or second for PolicySecret) to point to this session,
and transmits them to the device.
Errors
Returns InvalidCc when a command is not
a supported policy command.
Returns other TpmDeviceError variants when
TpmDevice::transmit fails.
Sourcepub fn flush(&self, device: &mut TpmDevice) -> Result<(), TpmDeviceError>
pub fn flush(&self, device: &mut TpmDevice) -> Result<(), TpmDeviceError>
Flushes the session context from the TPM.
Errors
Returns other TpmDeviceError variants when
TpmDevice::transmit fails.